﻿using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.Practices.EnterpriseLibrary.PolicyInjection;
using Microsoft.Practices.EnterpriseLibrary.Common.Configuration;
using System.Reflection;
using System.Windows.Forms;
using System.Diagnostics;

namespace PolicyInjectionQuickStart
{
	/// <summary>
	/// An <see cref="ICallHandler"/> that runs validation of a call's parameters
	/// before calling the target.
	/// </summary>
	[ConfigurationElementType(typeof(MyHandlerData))]
	public class MyHandler : ICallHandler
	{
		private string _myCustomProperty;

		public string MyCustomProperty
		{
			get { return _myCustomProperty; }
			set { _myCustomProperty = value; }
		}
	
		/// <summary>
		/// Creates a <see cref="MyHandler"/>.
		/// </summary>
		public MyHandler(string myCustomProperty)
		{
			_myCustomProperty = myCustomProperty;
		}

		/// <summary>
		/// Runs the call handler. 
		/// </summary>
		/// <param name="input"><see cref="IMethodInvocation"/> containing details of the current call.</param>
		/// <param name="getNext">Delegate to call to get the next handler in the pipeline.</param>
		/// <returns>Return value from the target.</returns>
		public IMethodReturn Invoke(IMethodInvocation input, GetNextHandlerDelegate getNext)
		{
			// do something before the method call here
			Debug.WriteLine("before method call : " + this.MyCustomProperty);

			// loop through the parameters passed into the method...
			for (int i = 0; i < input.Inputs.Count; i++)
			{
				ParameterInfo parameter = input.Inputs.GetParameterInfo(0);

				// ... and do something with the parameters here
			}

			// call the actual method
			IMethodReturn result = getNext()(input, getNext);

			if (result.Exception != null)
			{
				// do something with an exception that happened in the actual method
			}

			// do something after the method call here
			Debug.WriteLine("after method call : " + this.MyCustomProperty);

			return result;
		}
	}
}
