﻿using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.Practices.EnterpriseLibrary.PolicyInjection;
using Microsoft.Practices.EnterpriseLibrary.PolicyInjection.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Common.Configuration.ObjectBuilder;
using Microsoft.Practices.ObjectBuilder;
using Microsoft.Practices.EnterpriseLibrary.Common.Configuration;

namespace PolicyInjectionQuickStart
{
	/// <summary>
	/// Creates a <see cref="MyHandler"/> object from a configuration object.
	/// </summary>
	public class MyHandlerAssembler : IAssembler<ICallHandler, CallHandlerData>
	{
		/// <summary>
		/// Builds an instance of the subtype of <typeparamref name="TObject"/> type the receiver knows how to build,  based on 
		/// an a configuration object.
		/// </summary>
		/// <param name="context">The <see cref="IBuilderContext"/> that represents the current building process.</param>
		/// <param name="objectConfiguration">The configuration object that describes the object to build.</param>
		/// <param name="configurationSource">The source for configuration objects.</param>
		/// <param name="reflectionCache">The cache to use retrieving reflection information.</param>
		/// <returns>A fully initialized instance of the <typeparamref name="TObject"/> subtype.</returns>
		public ICallHandler Assemble(IBuilderContext context, CallHandlerData objectConfiguration, IConfigurationSource configurationSource, ConfigurationReflectionCache reflectionCache)
		{
			MyHandlerData castedHandlerData = (MyHandlerData)objectConfiguration;

			MyHandler callHandler = new MyHandler(castedHandlerData.MyCustomProperty);

			return callHandler;
		}
	}
}
