﻿using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.Practices.EnterpriseLibrary.PolicyInjection;

namespace PolicyInjectionQuickStart
{
	/// <summary>
	/// An attribute that applies the <see cref="MyHandler"/> to its target.
	/// </summary>
	[AttributeUsage(AttributeTargets.Class | AttributeTargets.Method | AttributeTargets.Property)]
	public class MyHandlerAttribute : HandlerAttribute
	{
		private string _myCustomProperty;

		public string MyCustomProperty
		{
			get { return _myCustomProperty; }
			set { _myCustomProperty = value; }
		}

		/// <summary>
		/// Constructs a new <see cref="MyHandlerAttribute"/>.
		/// </summary>
		public MyHandlerAttribute(string myCustomProperty)
		{
			_myCustomProperty = myCustomProperty;
		}

		/// <summary>
		/// Constructs a new <see cref="MyHandlerAttribute"/>.
		/// </summary>
		public MyHandlerAttribute()
		{
		}

		/// <summary>
		/// Derived classes implement this method. When called, it
		/// creates a new call handler as specified in the attribute
		/// configuration.
		/// </summary>
		/// <returns>A new call handler object.</returns>
		public override ICallHandler CreateHandler()
		{
			return new MyHandler(_myCustomProperty);
		}
	}

}
