﻿using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.Practices.EnterpriseLibrary.PolicyInjection.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Common.Configuration.ObjectBuilder;
using System.Configuration;

namespace PolicyInjectionQuickStart
{
	/// <summary>
	/// A configuration element class that stores the config data for
	/// the <see cref="MyHandler"/>.
	/// </summary>
	[Assembler(typeof(MyHandlerAssembler))]
	public class MyHandlerData : CallHandlerData
	{
		private const string MyCustomPropertyPropertyName = "myCustomProperty";

		/// <summary>
		/// Create a new <see cref="MyHandlerData"/> instance.
		/// </summary>
		public MyHandlerData()
			: base()
		{
		}

		/// <summary>
		/// Create a new <see cref="MyHandlerData"/> instance.
		/// </summary>
		/// <param name="handlerName">Name of handler in configuration.</param>
		public MyHandlerData(string handlerName)
			: base(handlerName, typeof(MyHandler))
		{
		}

		        /// <summary>
        /// Construct a new <see cref="MyHandlerData"/>.
        /// </summary>
        /// <param name="handlerName">Name of the handler.</param>
        /// <param name="myCustomProperty">My custom property.</param>
		public MyHandlerData(string handlerName, string myCustomProperty) 
            : base(handlerName, typeof(MyHandler))
        {
            MyCustomProperty = MyCustomProperty;
        }

        /// <summary>
        /// Some custom property.
        /// </summary>
        /// <value>The "myCustomProperty" attribute in configuration</value>
        [ConfigurationProperty(MyCustomPropertyPropertyName, IsRequired=true)]
        public string MyCustomProperty
        {
            get { return (string)base[MyCustomPropertyPropertyName]; }
            set { base[MyCustomPropertyPropertyName] = value; }
        }

	}

}
